@@ -17,7 +17,7 @@ class HandDetector:
     provides bounding box info of the hand found.
     """
 
-    def __init__(self, mode=False,maxHands=2, detectionCon=0.5, minTrackCon=0.5):
+    def __init__(self, mode=False, maxHands=2, detectionCon=0.5, minTrackCon=0.5):
         """
         :param mode: In static mode, detection is done on each image: slower
         :param maxHands: Maximum number of hands to detect
@@ -31,7 +31,8 @@ class HandDetector:
 
         self.mpHands = mp.solutions.hands
         self.hands = self.mpHands.Hands(static_image_mode=self.mode, max_num_hands=self.maxHands,
-                                        min_detection_confidence=self.detectionCon, min_tracking_confidence = self.minTrackCon)
+                                        min_detection_confidence=self.detectionCon,
+                                        min_tracking_confidence=self.minTrackCon)
         self.mpDraw = mp.solutions.drawing_utils
         self.tipIds = [4, 8, 12, 16, 20]
         self.fingers = []
@@ -48,16 +49,16 @@ class HandDetector:
         self.results = self.hands.process(imgRGB)
         allHands = []
         h, w, c = img.shape
-        if  self.results.multi_hand_landmarks:
-            for handType,handLms in zip(self.results.multi_handedness,self.results.multi_hand_landmarks):
-                myHand={}
+        if self.results.multi_hand_landmarks:
+            for handType, handLms in zip(self.results.multi_handedness, self.results.multi_hand_landmarks):
+                myHand = {}
                 ## lmList
                 mylmList = []
                 xList = []
                 yList = []
                 for id, lm in enumerate(handLms.landmark):
-                    px, py = int(lm.x * w), int(lm.y * h)
-                    mylmList.append([px, py])
+                    px, py, pz = int(lm.x * w), int(lm.y * h), int(lm.z * w)
+                    mylmList.append([px, py, pz])
                     xList.append(px)
                     yList.append(py)
 
@@ -71,14 +72,15 @@ class HandDetector:
 
                 myHand["lmList"] = mylmList
                 myHand["bbox"] = bbox
-                myHand["center"] =  (cx, cy)
+                myHand["center"] = (cx, cy)
 
                 if flipType:
-                    if handType.classification[0].label =="Right":
+                    if handType.classification[0].label == "Right":
                         myHand["type"] = "Left"
                     else:
                         myHand["type"] = "Right"
-                else:myHand["type"] = handType.classification[0].label
+                else:
+                    myHand["type"] = handType.classification[0].label
                 allHands.append(myHand)
 
                 ## draw
@@ -88,20 +90,20 @@ class HandDetector:
                     cv2.rectangle(img, (bbox[0] - 20, bbox[1] - 20),
                                   (bbox[0] + bbox[2] + 20, bbox[1] + bbox[3] + 20),
                                   (255, 0, 255), 2)
-                    cv2.putText(img,myHand["type"],(bbox[0] - 30, bbox[1] - 30),cv2.FONT_HERSHEY_PLAIN,
-                                2,(255, 0, 255),2)
+                    cv2.putText(img, myHand["type"], (bbox[0] - 30, bbox[1] - 30), cv2.FONT_HERSHEY_PLAIN,
+                                2, (255, 0, 255), 2)
         if draw:
-            return allHands,img
+            return allHands, img
         else:
             return allHands
 
-    def fingersUp(self,myHand):
+    def fingersUp(self, myHand):
         """
         Finds how many fingers are open and returns in a list.
         Considers left and right hands separately
         :return: List of which fingers are up
         """
-        myHandType =myHand["type"]
+        myHandType = myHand["type"]
         myLmList = myHand["lmList"]
         if self.results.multi_hand_landmarks:
             fingers = []
@@ -125,7 +127,7 @@ class HandDetector:
                     fingers.append(0)
         return fingers
 
-    def findDistance(self,p1, p2, img=None):
+    def findDistance(self, p1, p2, img=None):
         """
         Find the distance between two landmarks based on their
         index numbers.
@@ -148,7 +150,7 @@ class HandDetector:
             cv2.circle(img, (x2, y2), 15, (255, 0, 255), cv2.FILLED)
             cv2.line(img, (x1, y1), (x2, y2), (255, 0, 255), 3)
             cv2.circle(img, (cx, cy), 15, (255, 0, 255), cv2.FILLED)
-            return length,info, img
+            return length, info, img
         else:
             return length, info
 
@@ -184,7 +186,7 @@ def main():
                 fingers2 = detector.fingersUp(hand2)
 
                 # Find Distance between two Landmarks. Could be same hand or different hands
-                length, info, img = detector.findDistance(lmList1[8], lmList2[8], img)  # with draw
+                length, info, img = detector.findDistance(lmList1[8][0:2], lmList2[8][0:2], img)  # with draw
                 # length, info = detector.findDistance(lmList1[8], lmList2[8])  # with draw
         # Display
         cv2.imshow("Image", img)
